============================
 Invenio-Circulation v0.1.0
============================

Invenio-Circulation v0.1.0 was released on TBD, 2018.

About
-----

Invenio module for the circulation of bibliographic items.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-circulation==0.1.0

Documentation
-------------

   https://invenio-circulation.readthedocs.io/

Happy hacking and thanks for flying Invenio-Circulation.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-circulation
|   URL: http://inveniosoftware.org
